@@ -38,7 +38,10 @@ class _ECKey(SSHKey):
     pkcs8_oid = ObjectIdentifier('1.2.840.10045.2.1')
 
     def __init__(self, key):
+        super().__init__()
+
         self.algorithm = b'ecdsa-sha2-' + key.curve_id
+        self.sig_algorithms = (self.algorithm,)
         self._alg_oid = _alg_oids[key.curve_id]
         self._key = key
 
@@ -89,6 +92,13 @@ class _ECKey(SSHKey):
 
         return curve_id
 
+    @classmethod
+    def generate(cls, algorithm):
+        """Generate a new EC private key"""
+
+        # Strip 'ecdsa-sha2-' prefix of algorithm to get curve_id
+        return cls(ECDSAPrivateKey.generate(algorithm[11:]))
+
     @classmethod
     def make_private(cls, curve_id, private_key, public_key):
         """Construct an EC private key"""
@@ -96,13 +106,14 @@ class _ECKey(SSHKey):
         if isinstance(private_key, bytes):
             private_key = int.from_bytes(private_key, 'big')
 
-        return cls(ECDSAPrivateKey(curve_id, public_key, private_key))
+        return cls(ECDSAPrivateKey.construct(curve_id, public_key,
+                                             private_key))
 
     @classmethod
     def make_public(cls, curve_id, public_key):
         """Construct an EC public key"""
 
-        return cls(ECDSAPublicKey(curve_id, public_key))
+        return cls(ECDSAPublicKey.construct(curve_id, public_key))
 
     @classmethod
     def decode_pkcs1_private(cls, key_data):
@@ -239,15 +250,25 @@ class _ECKey(SSHKey):
         return b''.join((String(self._key.curve_id),
                          String(self._key.public_value)))
 
-    def sign(self, data):
+    def encode_agent_cert_private(self):
+        """Encode ECDSA certificate private key data for agent"""
+
+        if not self._key.d:
+            raise KeyExportError('Key is not private')
+
+        return MPInt(self._key.d)
+
+    def sign(self, data, algorithm):
         """Return a signature of the specified data using this key"""
 
         if not self._key.private_value:
             raise ValueError('Private key needed for signing')
 
+        if algorithm not in self.sig_algorithms:
+            raise ValueError('Unrecognized signature algorithm')
+
         r, s = self._key.sign(data)
-        sig = MPInt(r) + MPInt(s)
-        return b''.join((String(self.algorithm), String(sig)))
+        return b''.join((String(algorithm), String(MPInt(r) + MPInt(s))))
 
     def verify(self, data, sig):
         """Verify a signature of the specified data using this key"""
@@ -255,7 +276,7 @@ class _ECKey(SSHKey):
         try:
             packet = SSHPacket(sig)
 
-            if packet.get_string() != self.algorithm:
+            if packet.get_string() not in self.sig_algorithms:
                 return False
 
             sig = packet.get_string()
@@ -271,9 +292,9 @@ class _ECKey(SSHKey):
             return False
 
 
-for _curve_id, _oid in {(b'nistp521', '1.3.132.0.35'),
+for _curve_id, _oid in ((b'nistp521', '1.3.132.0.35'),
                         (b'nistp384', '1.3.132.0.34'),
-                        (b'nistp256', '1.2.840.10045.3.1.7')}:
+                        (b'nistp256', '1.2.840.10045.3.1.7')):
     _algorithm = b'ecdsa-sha2-' + _curve_id
     _cert_algorithm = _algorithm + b'-cert-v01@openssh.com'
 
@@ -281,5 +302,6 @@ for _curve_id, _oid in {(b'nistp521', '1.3.132.0.35'),
     _alg_oids[_curve_id] = _oid
     _alg_oid_map[_oid] = _curve_id
 
-    register_public_key_alg(_algorithm, _ECKey)
-    register_certificate_alg(_cert_algorithm, _ECKey, SSHCertificateV01)
+    register_public_key_alg(_algorithm, _ECKey, (_algorithm,))
+    register_certificate_alg(1, _algorithm, _cert_algorithm,
+                             _ECKey, SSHCertificateV01)
