@@ -27,6 +27,7 @@ class SSHSession:
            :type chan: :class:`SSHClientChannel`
 
         """
+        pass # pragma: no cover
 
     def connection_lost(self, exc):
         """Called when a channel is closed
@@ -42,17 +43,21 @@ class SSHSession:
 
         """
 
+        pass # pragma: no cover
+
     def session_started(self):
         """Called when the session is started
 
            This method is called when a session has started up. For
            client and server sessions, this will be called once a
            shell, exec, or subsystem request has been successfully
-           completed. For TCP sessions, it will be called immediately
-           after the connection is opened.
+           completed. For TCP and UNIX domain socket sessions, it will
+           be called immediately after the connection is opened.
 
         """
 
+        pass # pragma: no cover
+
     def data_received(self, data, datatype):
         """Called when data is received on the channel
 
@@ -67,10 +72,12 @@ class SSHSession:
            :param datatype:
                The extended data type of the data, from :ref:`extended
                data types <ExtendedDataTypes>`
-           :type data: string or bytes
+           :type data: str or bytes
 
         """
 
+        pass # pragma: no cover
+
     def eof_received(self):
         """Called when EOF is received on the channel
 
@@ -78,10 +85,19 @@ class SSHSession:
            on the channel, after which no more data will be received. If this
            method returns ``True``, the channel remains half open and data
            may still be sent. Otherwise, the channel is automatically closed
-           after this method returns. This is the default behavior.
+           after this method returns. This is the default behavior for
+           classes derived directly from :class:`SSHSession`, but not when
+           using the higher-level streams API. Because input is buffered
+           in that case, streaming sessions enable half-open channels to
+           allow applications to respond to input read after an end-of-file
+           indication is received.
 
         """
 
+        # pylint: disable=no-self-use
+
+        return False # pragma: no cover
+
     def pause_writing(self):
         """Called when the write buffer becomes full
 
@@ -93,6 +109,8 @@ class SSHSession:
 
         """
 
+        pass # pragma: no cover
+
     def resume_writing(self):
         """Called when the write buffer has sufficiently drained
 
@@ -102,6 +120,8 @@ class SSHSession:
 
         """
 
+        pass # pragma: no cover
+
 
 class SSHClientSession(SSHSession):
     """SSH client session handler
@@ -136,11 +156,13 @@ class SSHClientSession(SSHSession):
 
            By default, this message is ignored.
 
-           :param boolean client_can_do:
+           :param bool client_can_do:
                Whether or not to enable XON/XOFF flow control
 
         """
 
+        pass # pragma: no cover
+
     def exit_status_received(self, status):
         """A remote exit status has been received for this session
 
@@ -152,11 +174,13 @@ class SSHClientSession(SSHSession):
 
            By default, the exit status is ignored.
 
-           :param integer status:
+           :param int status:
                The exit status returned by the remote process
 
         """
 
+        pass # pragma: no cover
+
     def exit_signal_received(self, signal, core_dumped, msg, lang):
         """A remote exit signal has been received for this session
 
@@ -168,9 +192,9 @@ class SSHClientSession(SSHSession):
 
            By default, exit signals are ignored.
 
-           :param string signal:
+           :param str signal:
                The signal which caused the remote process to exit
-           :param boolean core_dumped:
+           :param bool core_dumped:
                Whether or not the remote process dumped core
            :param msg:
                Details about what error occurred
@@ -179,6 +203,8 @@ class SSHClientSession(SSHSession):
 
         """
 
+        pass # pragma: no cover
+
 
 class SSHServerSession(SSHSession):
     """SSH server session handler
@@ -219,7 +245,7 @@ class SSHServerSession(SSHSession):
            on the :class:`SSHServerChannel` to get the information they need
            after a shell, command, or subsystem is started.
 
-           :param string term:
+           :param str term_type:
                Terminal type to set for this session
            :param tuple term_size:
                Terminal size to set for this session provided as a
@@ -231,13 +257,14 @@ class SSHServerSession(SSHSession):
                are taken from :ref:`POSIX terminal modes <PTYModes>` with
                values defined in section 8 of :rfc:`4254#section-8`.
 
-           :returns: A boolean indicating if the request for a
+           :returns: A bool indicating if the request for a
                      pseudo-terminal was allowed or not
 
         """
 
         # pylint: disable=no-self-use,unused-argument
-        return True
+
+        return True # pragma: no cover
 
     def terminal_size_changed(self, width, height, pixwidth, pixheight):
         """The terminal size has changed
@@ -250,19 +277,21 @@ class SSHServerSession(SSHSession):
            wishing to use the terminal size can implement this method
            to get notified whenever it changes.
 
-           :param integer width:
+           :param int width:
                The width of the terminal in characters
-           :param integer height:
+           :param int height:
                The height of the terminal in characters
-           :param integer pixwidth: (optional)
+           :param int pixwidth: (optional)
                The width of the terminal in pixels
-           :param integer pixheight: (optional)
+           :param int pixheight: (optional)
                The height of the terminal in pixels
 
         """
 
         # pylint: disable=no-self-use,unused-argument
 
+        pass # pragma: no cover
+
     def shell_requested(self):
         """The client has requested a shell
 
@@ -277,13 +306,14 @@ class SSHServerSession(SSHSession):
 
            By default this method returns ``False`` to reject all requests.
 
-           :returns: A boolean indicating if the shell request was
+           :returns: A bool indicating if the shell request was
                      allowed or not
 
         """
 
         # pylint: disable=no-self-use,unused-argument
-        return False
+
+        return False # pragma: no cover
 
     def exec_requested(self, command):
         """The client has requested to execute a command
@@ -299,16 +329,17 @@ class SSHServerSession(SSHSession):
 
            By default this method returns ``False`` to reject all requests.
 
-           :param string command:
+           :param str command:
                The command the client has requested to execute
 
-           :returns: A boolean indicating if the exec request was
+           :returns: A bool indicating if the exec request was
                      allowed or not
 
         """
 
         # pylint: disable=no-self-use,unused-argument
-        return False
+
+        return False # pragma: no cover
 
     def subsystem_requested(self, subsystem):
         """The client has requested to start a subsystem
@@ -324,16 +355,17 @@ class SSHServerSession(SSHSession):
 
            By default this method returns ``False`` to reject all requests.
 
-           :param string subsystem:
+           :param str subsystem:
                The subsystem to start
 
-           :returns: A boolean indicating if the request to open the
+           :returns: A bool indicating if the request to open the
                      subsystem was allowed or not
 
         """
 
         # pylint: disable=no-self-use,unused-argument
-        return False
+
+        return False # pragma: no cover
 
     def break_received(self, msec):
         """The client has sent a break
@@ -346,16 +378,17 @@ class SSHServerSession(SSHSession):
            By default, this method returns ``False`` indicating that
            no break was performed.
 
-           :param integer msec:
+           :param int msec:
                The duration of the break in milliseconds
 
-           :returns: A boolean to indicate if the break operation was
+           :returns: A bool to indicate if the break operation was
                      performed or not
 
         """
 
         # pylint: disable=no-self-use,unused-argument
-        return False
+
+        return False # pragma: no cover
 
     def signal_received(self, signal):
         """The client has sent a signal
@@ -369,9 +402,11 @@ class SSHServerSession(SSHSession):
 
         # pylint: disable=no-self-use,unused-argument
 
+        pass # pragma: no cover
+
 
 class SSHTCPSession(SSHSession):
-    """SSH TCP connection session handler
+    """SSH TCP session handler
 
        Applications should subclass this when implementing a handler for
        SSH direct or forwarded TCP connections.
@@ -399,3 +434,36 @@ class SSHTCPSession(SSHSession):
        Received data will be passed to the :meth:`data_received` method.
 
     """
+
+
+class SSHUNIXSession(SSHSession):
+    """SSH UNIX domain socket session handler
+
+       Applications should subclass this when implementing a handler for
+       SSH direct or forwarded UNIX domain socket connections.
+
+       SSH client applications wishing to open a direct connection should call
+       :meth:`create_unix_connection()
+       <SSHClientConnection.create_unix_connection>` on their
+       :class:`SSHClientConnection`, passing in a factory which returns
+       instances of this class.
+
+       Server applications wishing to allow direct connections should
+       implement the coroutine :meth:`unix_connection_requested()
+       <SSHServer.unix_connection_requested>` on their :class:`SSHServer`
+       object and have it return instances of this class.
+
+       Server applications wishing to allow connection forwarding back
+       to the client should implement the coroutine
+       :meth:`unix_server_requested() <SSHServer.unix_server_requested>`
+       on their :class:`SSHServer` object and call
+       :meth:`create_unix_connection()
+       <SSHServerConnection.create_unix_connection>` on their
+       :class:`SSHServerConnection` for each new connection, passing it a
+       factory which returns instances of this class.
+
+       When a connection is successfully opened, :meth:`session_started`
+       will be called, after which the application can begin sending data.
+       Received data will be passed to the :meth:`data_received` method.
+
+    """
