@@ -28,7 +28,7 @@ from asyncssh import FXP_STATUS, FXP_HANDLE, FXP_DATA
 from asyncssh import FILEXFER_ATTR_UNDEFINED, FX_OK, FX_FAILURE
 
 from asyncssh.packet import SSHPacket, Byte, String, UInt32
-from asyncssh.sftp import SFTPServerHandler
+from asyncssh.sftp import SFTPHandler, SFTPServerHandler
 
 from .server import ServerTestCase
 from .util import asynctest, run
@@ -341,7 +341,7 @@ class _AsyncSFTPServer(SFTPServer):
 class _CheckSFTP(ServerTestCase):
     """Utility functions for AsyncSSH SFTP unit tests"""
 
-    def _create_file(self, name, data=(), mode=None):
+    def _create_file(self, name, data=(), mode=None, utime=None):
         """Create a test file"""
 
         if data is ():
@@ -353,6 +353,9 @@ class _CheckSFTP(ServerTestCase):
         if mode is not None:
             os.chmod(name, mode)
 
+        if utime is not None:
+            os.utime(name, utime)
+
     def _check_attr(self, name1, name2, follow_symlinks=False):
         """Check if attributes on two files are equal"""
 
@@ -369,13 +372,13 @@ class _CheckSFTP(ServerTestCase):
     def _check_file(self, name1, name2, preserve=False, follow_symlinks=False):
         """Check if two files are equal"""
 
+        if preserve:
+            self._check_attr(name1, name2, follow_symlinks)
+
         with open(name1, 'r') as file1:
             with open(name2, 'r') as file2:
                 self.assertEqual(file1.read(), file2.read())
 
-        if preserve:
-            self._check_attr(name1, name2, follow_symlinks)
-
     def _check_stat(self, sftp_stat, local_stat):
         """Check if file attributes are equal"""
 
@@ -424,7 +427,7 @@ class _TestSFTP(_CheckSFTP):
         for method in ('get', 'put', 'copy'):
             with self.subTest(method=method):
                 try:
-                    self._create_file('src', mode=0o400)
+                    self._create_file('src', mode=0o400, utime=(1, 2))
                     yield from getattr(sftp, method)('src', 'dst',
                                                      preserve=True)
                     self._check_file('src', 'dst', preserve=True)
@@ -1460,7 +1463,9 @@ class _TestSFTP(_CheckSFTP):
         def _non_version_response(self):
             """Send a non-version response to init"""
 
+            packet = yield from SFTPHandler.recv_packet(self)
             self.send_packet(Byte(FXP_STATUS))
+            return packet
 
         with patch('asyncssh.sftp.SFTPServerHandler.recv_packet',
                    _non_version_response):
