@@ -37,6 +37,8 @@ except (ImportError, OSError, AttributeError): # pragma: no cover
 
 # pylint: enable=unused-import
 
+from asyncssh.constants import DISC_CONNECTION_LOST
+from asyncssh.misc import DisconnectError, SignalReceived
 from asyncssh.packet import String, UInt32, UInt64
 
 
@@ -92,6 +94,11 @@ def echo(stdin, stdout, stderr=None):
             yield from stderr.drain()
 
         stdout.write_eof()
+    except SignalReceived as exc:
+        if exc.signal == 'ABRT':
+            raise DisconnectError(DISC_CONNECTION_LOST, 'Abort')
+        else:
+            stdin.channel.exit_with_signal(exc.signal)
     except OSError:
         pass
 
@@ -105,8 +112,9 @@ def _encode_options(options):
 
 
 def make_certificate(cert_version, cert_type, key, signing_key, principals,
-                     valid_after=0, valid_before=0xffffffffffffffff,
-                     options=None, extensions=None, bad_signature=False):
+                     key_id='name', valid_after=0,
+                     valid_before=0xffffffffffffffff, options=None,
+                     extensions=None, bad_signature=False):
     """Construct an SSH certificate"""
 
     keydata = key.encode_ssh_public()
@@ -116,8 +124,8 @@ def make_certificate(cert_version, cert_type, key, signing_key, principals,
     signing_keydata = b''.join((String(signing_key.algorithm),
                                 signing_key.encode_ssh_public()))
 
-    data = b''.join((String(cert_version), String(os.urandom(8)), keydata,
-                     UInt64(0), UInt32(cert_type), String(''),
+    data = b''.join((String(cert_version), String(os.urandom(32)), keydata,
+                     UInt64(0), UInt32(cert_type), String(key_id),
                      String(principals), UInt64(valid_after),
                      UInt64(valid_before), String(options),
                      String(extensions), String(''), String(signing_keydata)))
@@ -125,7 +133,7 @@ def make_certificate(cert_version, cert_type, key, signing_key, principals,
     if bad_signature:
         data += String('')
     else:
-        data += String(signing_key.sign(data))
+        data += String(signing_key.sign(data, signing_key.algorithm))
 
     return b''.join((cert_version.encode('ascii'), b' ',
                      binascii.b2a_base64(data)))
